///////////////////////////////////////////////////////////////////////////////
// ViewMain.cpp
// ============
// View component
//
//  AUTHOR: Song Ho Ahn (song.ahn@gmail.com)
// CREATED: 2007-06-07
// UPDATED: 2020-01-15
///////////////////////////////////////////////////////////////////////////////


#include "ViewMain.h"
#include "resource.h"
#include "Log.h"
#include <sstream>
using namespace Win;



///////////////////////////////////////////////////////////////////////////////
// ctor/dtor
///////////////////////////////////////////////////////////////////////////////
ViewMain::ViewMain()
{
}
ViewMain::~ViewMain()
{
    ::ImageList_Destroy(imageList);
}



///////////////////////////////////////////////////////////////////////////////
// initialize all controls
///////////////////////////////////////////////////////////////////////////////
void ViewMain::init(HWND handle)
{
    // create ImageList
    const int IMAGE_WIDTH = 16;
    const int IMAGE_HEIGHT = 16;
    const int IMAGE_COUNT = 3;
    const int GROW_SIZE = 4;                    // the number of images when ImageList needs to grow for new images

    // create ImageList control first
    imageList = ::ImageList_Create(IMAGE_WIDTH, IMAGE_HEIGHT, ILC_COLORDDB | ILC_MASK, IMAGE_COUNT, GROW_SIZE);

    tab.set(handle, IDC_TAB);
    buttonExit.set(handle, IDC_EXIT);

    // load icons and add them to ImageList
    // PARAMS: hInstance, filename, type, width, height, flag
    HICON icon = (HICON)::LoadImage(::GetModuleHandle(0), MAKEINTRESOURCE(IDI_FAVORITES), IMAGE_ICON, IMAGE_WIDTH, IMAGE_HEIGHT, LR_DEFAULTCOLOR);
    ::ImageList_AddIcon(imageList, icon);
    icon = (HICON)::LoadImage(::GetModuleHandle(0), MAKEINTRESOURCE(IDI_INFO), IMAGE_ICON, IMAGE_WIDTH, IMAGE_HEIGHT, LR_DEFAULTCOLOR);
    ::ImageList_AddIcon(imageList, icon);
    icon = (HICON)::LoadImage(::GetModuleHandle(0), MAKEINTRESOURCE(IDI_APPDEFAULT), IMAGE_ICON, IMAGE_WIDTH, IMAGE_HEIGHT, LR_DEFAULTCOLOR);
    ::ImageList_AddIcon(imageList, icon);

    // make sure all icons are in the ImageList
    if(::ImageList_GetImageCount(imageList) == IMAGE_COUNT)
    {
        tab.setImageList(imageList);
    }

    // add items to tab control: tabIndex, title, imageIndex
    tab.insertItem(0, L"Tab View #1", 0);
    tab.insertItem(1, L"Tab View #2", 1);
    tab.insertItem(2, L"Tab View #3", 2);

    /*
    // debug
    tab.deselectAll();
    //tab.setCurFocus(1);
    //tab.setCurSel(2);
    Win::log(L"Curr Focus: %d", tab.getCurFocus());
    //tab.deleteItem(2);
    Win::log(L"Item Count: %d", tab.getItemCount());
    tab.highlightItem(1, false); // false means default
    //tab.removeImage(0);
    //TCITEM tcItem;
    //tcItem.mask = TCIF_TEXT;
    //tab.getItem(0, &tcItem);
    //Win::log("Tab Item: %ls", tcItem.pszText); // CRASH
    //tab.setItemSize(100, 32);
    int prevWidth = tab.setMinTabWidth(100);
    tab.getItemRect(0, &rect);
    Win::log(L"Item Rect: (%d, %d, %d, %d)", rect.left, rect.right, rect.top, rect.bottom);
    int currWidth = rect.right - rect.left;
    Win::log(L"Prev Width: %d", prevWidth);
    Win::log(L"Curr Width: %d", currWidth);
    */
}



///////////////////////////////////////////////////////////////////////////////
// Tab Control notifications
///////////////////////////////////////////////////////////////////////////////
void ViewMain::tcFocusChange()
{
}

void ViewMain::tcGetObject(NMOBJECTNOTIFY* objectNotify)
{
    // objectNotify->hdr
    // objectNotify->iItem
    // objectNotify->piid
    // objectNotify->pObject
    // objectNotify->hResult
    // objectNotify->dwFlags
}

void ViewMain::tcKeyDown(NMTCKEYDOWN* keyDown)
{
    // keydown->hdr
    // keydown->wVKey
    // keydown->flags
}

void ViewMain::tcSelChange()
{
}



